bayespy.inference.vmp.nodes.beta.BetaDistribution.random
========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaDistribution.random